@@ -22,8 +22,8 @@ class DatasetTest(unittest.TestCase):
             'glass_ternary_hipt',
             'double_perovskites_gap',
             'double_perovskites_gap_lumo',
-            'mp_all',
-            'mp_nostruct',
+            'mp_all_20181018',
+            'mp_nostruct_20181018',
             'glass_ternary_landolt',
             'citrine_thermal_conductivity',
             'wolverton_oxides',
