@@ -77,6 +77,15 @@ class SiteDOS(BaseFeaturizer):
                 labels.append('{}_{}'.format(edge, score))
         return labels
 
+    def citations(self):
+        return ["@article{dylla2020machine,"
+        "title={Machine Learning Chemical Guidelines for Engineering Electronic Structures in Half-Heusler Thermoelectric Materials},"
+        "author={Dylla, Maxwell T and Dunn, Alexander and Anand, Shashwat and Jain, Anubhav and Snyder, G Jeffrey and others},"
+        "journal={Research}, volume={2020}, pages={6375171}, year={2020}, publisher={AAAS}}"]
+
+    def implementors(self):
+        return ["Max Dylla"]
+
 
 class DOSFeaturizer(BaseFeaturizer):
     """
@@ -174,6 +183,12 @@ class DOSFeaturizer(BaseFeaturizer):
 
         return labels
 
+    def citations(self):
+        return ["@article{dylla2020machine,"
+                "title={Machine Learning Chemical Guidelines for Engineering Electronic Structures in Half-Heusler Thermoelectric Materials},"
+                "author={Dylla, Maxwell T and Dunn, Alexander and Anand, Shashwat and Jain, Anubhav and Snyder, G Jeffrey and others},"
+                "journal={Research}, volume={2020}, pages={6375171}, year={2020}, publisher={AAAS}}"]
+
     def implementors(self):
         return ['Maxwell Dylla', 'Alireza Faghaninia', 'Anubhav Jain']
 
@@ -373,6 +388,12 @@ class Hybridization(BaseFeaturizer):
                 labels.append('{}_{}'.format(ex, hybrid))
         return labels
 
+    def citations(self):
+        return ["@article{dylla2020machine,"
+        "title={Machine Learning Chemical Guidelines for Engineering Electronic Structures in Half-Heusler Thermoelectric Materials},"
+        "author={Dylla, Maxwell T and Dunn, Alexander and Anand, Shashwat and Jain, Anubhav and Snyder, G Jeffrey and others},"
+        "journal={Research}, volume={2020}, pages={6375171}, year={2020}, publisher={AAAS}}"]
+
     def implementors(self):
         return ['Alireza Faghaninia', 'Anubhav Jain', 'Maxwell Dylla']
 
@@ -447,6 +468,9 @@ class DosAsymmetry(BaseFeaturizer):
         """
         return ['dos_asymmetry']
 
+    def citations(self):
+        return []
+
     def implementors(self):
         return ['Maxwell Dylla']
 
