@@ -133,6 +133,9 @@ class DemlData(OxidationStateDependentData, OxidationStatesMixin):
     theory total energies and enthalpies of formation of metal-nonmetal
     compounds by linear regression, Phys. Rev. B - Condens. Matter Mater. Phys.
     93 (2016).
+
+    The meanings of each feature in the data can be found in
+    ./data_files/deml_elementdata.py
     """
 
     def __init__(self):
@@ -186,6 +189,10 @@ class MagpieData(AbstractData, OxidationStatesMixin):
     L. Ward, A. Agrawal, A. Choudhary, C. Wolverton, A general-purpose machine
     learning framework for predicting properties of inorganic materials,
     Npj Comput. Mater. 2 (2016) 16028.
+
+
+    Finding the exact meaning of each of these features can be quite difficult.
+    Reproduced in ./data_files/magpie_elementdata_feature_descriptions.txt.
     """
 
     def __init__(self):
@@ -231,6 +238,9 @@ class PymatgenData(OxidationStateDependentData, OxidationStatesMixin):
     S.P. Ong, W.D. Richards, A. Jain, G. Hautier, M. Kocher, S. Cholia, et al.,
     Python Materials Genomics (pymatgen): A robust, open-source python library
     for materials analysis, Comput. Mater. Sci. 68 (2013) 314-319.
+
+    Meanings of each feature can be obtained from the pymatgen.Composition
+    documentation (attributes).
     """
 
     def __init__(self, use_common_oxi_states=True):
@@ -316,7 +326,12 @@ class MatscholarElementData(AbstractData):
     generated using NLP + Neural Network techniques on more than 3 million
     scientific abstracts.
 
-    #TODO: add citation (expected mid-2019).
+    The data returned by this class are simply learned representations of the
+    elements, taken from:
+
+    Tshitoyan, V., Dagdelen, J., Weston, L. et al. Unsupervised word embeddings
+    capture latent knowledge from materials science literature. Nature 571,
+    95–98 (2019). https://doi.org/10.1038/s41586-019-1335-8
     """
 
     def __init__(self):
@@ -338,20 +353,23 @@ class MEGNetElementData(AbstractData):
     """
     Class to get neural network embeddings of elements. These embeddings were
     generated using the Materials Graph Network (MEGNet) developed by the
-    MaterialsVirtualLab at U.C. San Diego and described in the following
-    preprint:
+    MaterialsVirtualLab at U.C. San Diego and described in the publication:
 
-    https://arxiv.org/abs/1812.05055
+    Graph Networks as a Universal Machine Learning Framework for Molecules and
+    Crystals. Chi Chen, Weike Ye, Yunxing Zuo, Chen Zheng, and Shyue Ping Ong
+    Chemistry of Materials 2019 31 (9), 3564-3572,
+    https://doi.org/10.1021/acs.chemmater.9b01294
 
     The code for MEGNet can be found at:
     https://github.com/materialsvirtuallab/megnet
 
-    #TODO: add publication reference when MEGNet is published
-
     The embeddings were generated by training the MEGNet Graph Network on
     60,000 structures from the Materials Project for predicting formation
     energy, and may be an effective way of applying transfer learning to
     smaller datasets using crystal-graph-based networks.
+
+    The representations are learned during training to predict a specific
+    property, though they may be useful for a range of properties.
     """
 
     def __init__(self):
